![Keeper Commander Header](https://github.com/user-attachments/assets/a690bcd6-95b2-4792-b17a-8ff1389c2b27)

![Keeper Commander](https://raw.githubusercontent.com/Keeper-Security/Commander/master/images/commander-black.png)

### About Keeper Commander
Keeper Commander is a command-line CLI and Python SDK interface to Keeper® Password Manager and KeeperPAM. Commander can be used to access and control your Keeper vault, perform administrative functions (managing users, teams, roles, SSO, privileged access resources, data import/export), launch sessions, rotate passwords, integrate with developer tools, eliminate hardcoded passwords, run as a REST service and more. Keeper Commander is an open source project with contributions from Keeper's engineering team and partners.

### Documentation and Getting Started
- Keeper Commander documentation: [https://docs.keeper.io/en/keeperpam/commander-cli/overview](https://docs.keeper.io/en/keeperpam/commander-cli/overview)

### About Keeper Security
Keeper is the leading cybersecurity platform for preventing password-related data breaches and cyberthreats. KeeperPAM is the leading zero-trust privileged access management ("PAM") platform for securing and managing access to your critical infrastructure.

- Learn More about Keeper: [https://keepersecurity.com](https://keepersecurity.com)

- Encryption and Security Model: [https://docs.keeper.io/en/enterprise-guide/keeper-encryption-model](https://docs.keeper.io/en/enterprise-guide/keeper-encryption-model)

- Documentation Home: [https://docs.keeper.io/](https://docs.keeper.io/)
